IntelligenceResponse class

Constructors

IntelligenceResponse({String? requestId, String? deviceId, String? sessionId, List<String>? clientUserIds, bool? newDevice, String? ip, bool? vpn, bool? proxy, bool? geoSpoofed, bool? appTampering, bool? hooking, bool? factoryReset, bool? mirroredScreen, bool? cloned, double? deviceRiskScore, double? sessionRiskScore, int? factoryResetTime, Map<String, String>? additionalData, AppliedRules? appliedRules, bool? genuineInstall, bool? harmfulAppDetected, bool? blacklistedDevice, bool? developerOptionsEnabled, bool? usbDebugging, bool? wirelessDebugging, bool? unsecuredWifi, bool? keyloggerDetected, RuleAction? ruleAction, bool? emulator, bool? remoteAppProviders, int? remoteAppProvidersCount, bool? rooted, AllSimInfo? simInfo, DeviceMeta? deviceMeta, AppAnalytics? appAnalytics, IPDetails? ipDetails, GPSLocationData? gpsLocation, bool? simulator, bool? jailbroken})
IntelligenceResponse.fromAndroidJson(Map<String, dynamic> json)
Android-specific constructor
IntelligenceResponse.fromIosJson(Map<String, dynamic> json)
iOS-specific constructor

Properties

additionalData ↔ Map<String, String>?
getter/setter pair
appAnalytics ↔ AppAnalytics?
getter/setter pair
appliedRules ↔ AppliedRules?
getter/setter pair
appTampering ↔ bool?
getter/setter pair
blacklistedDevice ↔ bool?
getter/setter pair
clientUserIds ↔ List<String>?
getter/setter pair
cloned ↔ bool?
getter/setter pair
developerOptionsEnabled ↔ bool?
getter/setter pair
deviceId ↔ String?
getter/setter pair
deviceMeta ↔ DeviceMeta?
getter/setter pair
deviceRiskScore ↔ double?
getter/setter pair
emulator ↔ bool?
getter/setter pair
factoryReset ↔ bool?
getter/setter pair
factoryResetTime ↔ int?
getter/setter pair
genuineInstall ↔ bool?
getter/setter pair
geoSpoofed ↔ bool?
getter/setter pair
gpsLocation ↔ GPSLocationData?
getter/setter pair
harmfulAppDetected ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hooking ↔ bool?
getter/setter pair
ip ↔ String?
getter/setter pair
ipDetails ↔ IPDetails?
getter/setter pair
jailbroken ↔ bool?
getter/setter pair
keyloggerDetected ↔ bool?
getter/setter pair
mirroredScreen ↔ bool?
getter/setter pair
newDevice ↔ bool?
getter/setter pair
proxy ↔ bool?
getter/setter pair
remoteAppProviders ↔ bool?
getter/setter pair
remoteAppProvidersCount ↔ int?
getter/setter pair
requestId ↔ String?
getter/setter pair
rooted ↔ bool?
getter/setter pair
ruleAction ↔ RuleAction?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
getter/setter pair
sessionRiskScore ↔ double?
getter/setter pair
simInfo ↔ AllSimInfo?
getter/setter pair
simulator ↔ bool?
getter/setter pair
unsecuredWifi ↔ bool?
getter/setter pair
usbDebugging ↔ bool?
getter/setter pair
vpn ↔ bool?
getter/setter pair
wirelessDebugging ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonAndroid() → Map<String, dynamic>
toJsonIos() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited