Options class

Constructors

Options({required String clientId, required String clientSecret, String? sessionId, required Environment environment, String? phoneNumber, PhoneInputType? phoneInputType, OtpInputType? otpInputType, String? userId, UserEventType? userEventType, String? merchantId, Map<String, String> additionalAttributes = const {}})
Options.fromJson(Map<String, dynamic> map)
factory

Properties

additionalAttributes → Map<String, String>
final
clientId → String
final
clientSecret → String
final
environment → Environment
final
hashCode → int
The hash code for this object.
no setterinherited
merchantId → String?
final
otpInputType → OtpInputType?
final
phoneInputType → PhoneInputType?
final
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
final
userEventType → UserEventType?
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited