OptionsBuilder class

Constructors

OptionsBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → Options
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdditionalAttributes(Map<String, String> additionalAttributes) → OptionsBuilder
setClientId(String clientId) → OptionsBuilder
setClientSecret(String clientSecret) → OptionsBuilder
setEnvironment(Environment environment) → OptionsBuilder
setMerchantId(String? merchantId) → OptionsBuilder
setOtpInputType(OtpInputType? otpInputType) → OptionsBuilder
setPhoneInputType(PhoneInputType? phoneInputType) → OptionsBuilder
setPhoneNumber(String? phoneNumber) → OptionsBuilder
setSessionId(String? sessionId) → OptionsBuilder
setUserEventType(UserEventType? userEventType) → OptionsBuilder
setUserId(String? userId) → OptionsBuilder
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited