SimDetails class

Constructors

SimDetails({String? carrierName, int? id, int? simSlotIndex, bool? eSim})
SimDetails.fromJson(Map<String, dynamic> json)
factory

Properties

carrierName ↔ String?
getter/setter pair
eSim ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simSlotIndex ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited