UpdateOptionsBuilder class

Constructors

UpdateOptionsBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → UpdateOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAdditionalAttributes(Map<String, String> additionalAttributes) → UpdateOptionsBuilder
setMerchantId(String? merchantId) → UpdateOptionsBuilder
setOtpInputType(OtpInputType? otpInputType) → UpdateOptionsBuilder
setPhoneInputType(PhoneInputType? phoneInputType) → UpdateOptionsBuilder
setPhoneNumber(String? phoneNumber) → UpdateOptionsBuilder
setUserEventType(UserEventType? userEventType) → UpdateOptionsBuilder
setUserId(String? userId) → UpdateOptionsBuilder
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited